@@ -1,17 +1,22 @@
 from __future__ import absolute_import
 
 import sys
+from sentry_sdk.consts import OP
 
 from sentry_sdk.hub import Hub
-from sentry_sdk.utils import capture_internal_exceptions, event_from_exception
+from sentry_sdk.tracing import TRANSACTION_SOURCE_TASK
+from sentry_sdk.utils import (
+    capture_internal_exceptions,
+    event_from_exception,
+)
 from sentry_sdk.tracing import Transaction
 from sentry_sdk._compat import reraise
 from sentry_sdk.integrations import Integration, DidNotEnable
 from sentry_sdk.integrations.logging import ignore_logger
-from sentry_sdk._types import MYPY
+from sentry_sdk._types import TYPE_CHECKING
 from sentry_sdk._functools import wraps
 
-if MYPY:
+if TYPE_CHECKING:
     from typing import Any
     from typing import TypeVar
     from typing import Callable
@@ -23,7 +28,7 @@ if MYPY:
 
 
 try:
-    from celery import VERSION as CELERY_VERSION  # type: ignore
+    from celery import VERSION as CELERY_VERSION
     from celery.exceptions import (  # type: ignore
         SoftTimeLimitExceeded,
         Retry,
@@ -99,7 +104,9 @@ def _wrap_apply_async(f):
         hub = Hub.current
         integration = hub.get_integration(CeleryIntegration)
         if integration is not None and integration.propagate_traces:
-            with hub.start_span(op="celery.submit", description=args[0].name) as span:
+            with hub.start_span(
+                op=OP.QUEUE_SUBMIT_CELERY, description=args[0].name
+            ) as span:
                 with capture_internal_exceptions():
                     headers = dict(hub.iter_trace_propagation_headers(span))
 
@@ -152,10 +159,10 @@ def _wrap_tracer(task, f):
             with capture_internal_exceptions():
                 transaction = Transaction.continue_from_headers(
                     args[3].get("headers") or {},
-                    op="celery.task",
+                    op=OP.QUEUE_TASK_CELERY,
                     name="unknown celery task",
+                    source=TRANSACTION_SOURCE_TASK,
                 )
-
                 transaction.name = task.name
                 transaction.set_status("ok")
 
